LCOGT Data Reduction Package
============================

This repo contains the data reduction pacakge for LCOGT.

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

Status reports for developers
-----------------------------

.. image:: https://travis-ci.org/LCOGT/banzai.png?branch=master
    :target: https://travis-ci.org/LCOGT/banzai
    :alt: Test Status

